﻿using System;
using System.Linq;
using System.Windows.Forms;

namespace ElmarBoye.Samples.Forms
{
    public partial class CustomerGridForm : Form
    {
        // PersonID für Einstellungen (Vorgabe 4711)
        private int PersonId { get; set; }
        // Verbindungszeichenfolge
        private string ConnectionString { get; set; }

        public CustomerGridForm()
        {
            InitializeComponent();

            // Einstellungen aus den Settings
            this.ConnectionString = Properties.Settings.Default.ConnectionString;
            this.PersonId = Properties.Settings.Default.PersonID;

            // Anzeige PersonID
            this.Text = this.Text + " - " + this.PersonId.ToString();

            // Umsortieren erlauben
            this.customersDataGridView.AllowUserToOrderColumns = true;
            
/*
            // Ausblenden von zwei Spalten (Für Test von Visible)
            var columns =
                from c in this.customersDataGridView.Columns.Cast<DataGridViewColumn>()
                where c.DataPropertyName == "Region" || c.DataPropertyName == "PostalCode"
                select c;
            foreach (var column in columns)
                column.Visible = false;
*/
        }

        private void customersBindingNavigatorSaveItem_Click(object sender, EventArgs e)
        {
            try
            {
                this.Validate();
                this.customersBindingSource.EndEdit();
                this.tableAdapterManager.UpdateAll(this.northwindDataSet);
            }
            catch (Exception ex)
            {
                ShowError(ex);
            }
        }

        private void CustomerGridForm_Load(object sender, EventArgs e)
        {
            try
            {
                // Laden Layout
                this.loadGridLayoutButton.PerformClick();

                // Daten abrufen
                this.customersTableAdapter.Fill(this.northwindDataSet.Customers);
            }
            catch (Exception ex)
            {
                ShowError(ex);
            }
        }

        private void saveGridLayoutButton_Click(object sender, EventArgs e)
        {
            try
            {
                // Speichert das GridLayout            
                using (var einstellungen = new GridEinstellungen(this.ConnectionString))
                {
                    einstellungen.SaveLayout(PersonId, this.customersDataGridView);
                }
            }
            catch (Exception ex)
            {
                ShowError(ex);
            }
        }

        private void loadGridLayoutButton_Click(object sender, EventArgs e)
        {
            try
            {
                // Lädt das GridLayout            
                using (var einstellungen = new GridEinstellungen(this.ConnectionString))
                {
                    einstellungen.LoadLayout(PersonId, this.customersDataGridView);
                }
            }
            catch (Exception ex)
            {
                ShowError(ex);
            }
        }

        private void ShowError(Exception ex)
        {
            MessageBox.Show(this, ex.Message, this.Text, MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
}

